package com.dkl.large.service;

import com.koal.kms.sdk.ed.KmsSdkException;
import com.dkl.common.core.domain.entity.SysUser;
import com.dkl.large.domain.DklActivity;

import java.util.List;

/**
 * 大客流活动Service接口
 *
 * @author Dkl
 * @date 2025-05-27
 */
public interface IDklActivityService
{
    /**
     * 查询大客流活动
     *
     * @param id 大客流活动主键
     * @return 大客流活动
     */
    public DklActivity selectDklActivityById(int id) throws KmsSdkException;

    /**
     * 查询大客流活动列表
     *
     * @param dklActivity 大客流活动
     * @return 大客流活动集合
     */
    public List<DklActivity> selectDklActivityList(DklActivity dklActivity) throws KmsSdkException;
    public String selectDklActivityListMessage(DklActivity dklActivity) throws KmsSdkException;
    /**
     * 新增大客流活动
     *
     * @param dklActivity 大客流活动
     * @return 结果
     */
    public int insertDklActivity(DklActivity dklActivity) throws KmsSdkException;

    /**
     * 修改大客流活动
     *
     * @param dklActivity 大客流活动
     * @return 结果
     */
    public int updateDklActivity(DklActivity dklActivity) throws KmsSdkException;

    /**
     * 批量删除大客流活动
     *
     * @param ids 需要删除的大客流活动主键集合
     * @return 结果
     */
    public int deleteDklActivityByIds(int[] ids);

    /**
     * 删除大客流活动信息
     *
     * @param id 大客流活动主键
     * @return 结果
     */
    public int deleteDklActivityById(int id);

    /**
     * @Author :rq
     * @Description :大屏预警信息统计
     * @Date :2025/06/09 10:22
     * @Param :[]
     * @return :java.util.List<com.dkl.large.domain.DklActivity>
     **/
    List<DklActivity> ativityEarlyWarning(DklActivity dklActivity);
    /**
     * @Author :rq
     * @Description :大屏重点场所热力图/景区热力图
     * @Date :2025/06/09 13:22
     * @Param :[]
     * @return :java.util.List<com.dkl.large.domain.DklActivity>
     **/
    public List<DklActivity> thermogramStatistics(DklActivity dklActivity);

    /**
     * @Author :rq
     * @Description :大客流活动统计首页
     * @Date :2025/07/11 10:42
     * @Param :[dklActivity]
     * @return :java.util.List<com.dkl.large.domain.DklActivity>
     **/
    public List<DklActivity> homeActivityStatistics(DklActivity dklActivity);
    /**
     * @Author :rq
     * @Description :大客流活动人数统计首页
     * @Date :2025/07/11 15:42
     * @Param :[dklActivity]
     * @return :java.util.List<com.dkl.large.domain.DklActivity>
     **/
    public List<DklActivity> homeActivityStatisticsPeople(DklActivity dklActivity);
    /**
     * 导入数据
     *
     * @param activityList 数据列表
     * @param operName 操作用户
     * @return 结果
     */
    public String importDate(List<DklActivity> activityList,String operName) throws KmsSdkException;


    public boolean checkActivityNameUnique(DklActivity dklActivity);
}
